// define the KSniffer version

#ifndef APPVER
#define APPVER "0.3.2"
#endif

#ifndef TEMP_PCAP_FILE_NAME
#define TEMP_PCAP_FILE_NAME "ksniffer.pcap"
#endif

#ifndef TEMP_SNIFFER_CONFIG_FILE_NAME
#define TEMP_SNIFFER_CONFIG_FILE_NAME "ksniffer.xml"
#endif
